# Rave

Rave is a Python package that models the structure of edge-on debris disks nonparametrically. 

Given an input image of a highly inclined (edge-on, or nearly edge-on) debris disk, Rave recovers the face-on surface brightness as a function of radius and vertical height of the disk as a function of radius. 

## Publication
See [link to paper] for details. 

## Installation
Rave is available at https://pypi.org/project/rave/ and we recommend installing via

`pip install rave`

## Demo
See ./demo for demos.
